Skip to main contentCrate include_crypt
Source - include_crypt
- Macro that can be used to safely embed files into the binary.
- include_dir
- Macro that can be used to safely embed a folder into the binary.
- EncryptedFile
- The structure which is used to store the encrypted buffer and the decryption
keys.
- EncryptedFolder
- The folder with all the encrypted files.
- EncryptionType
- The different encryption types with their encryption keys. The obfuscated
strings have double the size because of the hex encoding.